Package: Omixer
Type: Package
Title: Omixer: multivariate and reproducible sample randomization to
        proactively counter batch effects in omics studies
Version: 1.23.0
Authors@R: person("Lucy", "Sinke", 
    email="l.j.sinke@lumc.nl", role=c("cre", "aut"))
Description: Omixer - an Bioconductor package for multivariate and 
    reproducible sample randomization, which ensures optimal sample 
    distribution across batches with well-documented methods. It outputs 
    lab-friendly sample layouts, reducing the risk of sample mixups when 
    manually pipetting randomized samples. 
License: MIT + file LICENSE
Encoding: UTF-8
Imports: dplyr, ggplot2, forcats, tibble, gridExtra, magrittr, readr,
        tidyselect, grid, stats, stringr
Depends: R (>= 4.0.0)
RoxygenNote: 7.1.1
Suggests: knitr, rmarkdown, BiocStyle, magick, testthat
VignetteBuilder: knitr
biocViews: DataRepresentation, ExperimentalDesign, QualityControl,
        Software, Visualization
BugReports: https://github.com/molepi/Omixer/issues
git_url: https://git.bioconductor.org/packages/Omixer
git_branch: devel
git_last_commit: d1f35a9
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:09:42 UTC; biocbuild
Author: Lucy Sinke [cre, aut]
Maintainer: Lucy Sinke <l.j.sinke@lumc.nl>
