# Generated by roxygen2: do not edit by hand

export(omixerCorr)
export(omixerRand)
export(omixerSheet)
export(omixerSpecific)
import(dplyr)
import(forcats)
import(ggplot2)
import(magrittr)
import(stringr)
import(tibble)
importFrom(dplyr,filter)
importFrom(dplyr,select)
importFrom(forcats,as_factor)
importFrom(grid,unit)
importFrom(gridExtra,marrangeGrob)
importFrom(readr,write_csv)
importFrom(readr,write_csv2)
importFrom(readr,write_delim)
importFrom(stats,chisq.test)
importFrom(stats,cor.test)
importFrom(tibble,tibble)
importFrom(tidyselect,all_of)
importFrom(tidyselect,everything)
