#' Multivariate Randomization
#'
#' Omixer provides functions to perform optimal randomization of
#' sample lists prior to omic profiling. This minimizes the
#' correlation between biological factors and technical covariates,
#' whilst ensuring there is insufficient evidence for any of
#' these associations.
#'
#' Following this multivariate randomization, Omixer can also be
#' used to smoothly bridge the gap between dry and wet labs, by
#' creating visually intuitive sample sheets.
#'
#' With clear documentation and the possibility to reproduce any
#' output sample list, Omixer sets the standard for transparency
#' and reproducibility in this often vague methodological step.
#'
#' @docType package
#'
#' @author Lucy Sinke \email{l.j.sinke@lumc.nl}
#'
#' @name Omixer
NULL
